# Edit this configuration file to define what should be installed on
# your system. Help is available in the configuration.nix(5) man page, on
# https://search.nixos.org/options and in the NixOS manual (`nixos-help`).
{
  # config,
  lib,
  pkgs,
  ...
}: {
  imports = [
    # Include the results of the hardware scan.
    ./hardware-configuration.nix
  ];

  sops.defaultSopsFile = ./secrets/secrets.yaml;
  sops.defaultSopsFormat = "yaml";
  
  sops.age.keyFile = "/home/tacocat/.config/sops/age/keys.txt";

  boot.loader = {
    efi.canTouchEfiVariables = false;
    grub = {
      efiSupport = true;
      configurationLimit = 10;
      device = "nodev";
      # extraEntriesBeforeNixOS = true; # still primarily using void
      extraEntries = ''
        menuentry "Void" {
          search --set=void --fs-uuid 987518fa-8ea0-49a6-b1e5-1fed4e4ae50f
          configfile "($void)/boot/grub/grub.cfg"
        }
      '';
    };
  };

  nix.settings.experimental-features = ["nix-command" "flakes"];
  nix.settings.auto-optimise-store = true;
  nix.settings.trusted-users = ["root" "tacocat"];

  nix.gc = {
    automatic = true;
    dates = "weekly";
    options = "--delete-older-than 1w";
  };

  networking.hostName = "JWST";
  networking.networkmanager.enable = true;

  # Select internationalisation properties.
  i18n.defaultLocale = "en_US.UTF-8";
  console = {
    font = "Lat2-Terminus16";
    keyMap = "us";
  };

  time.timeZone = "America/New_York";

  # Enable CUPS to print documents.
  services.printing.enable = true;
  services.geoclue2.enable = true;
  # services.tlp.enable = true;
  # services.thermald.enable = true;

  # Enable sound.
  sound.enable = true;
  services.pipewire = {
    enable = true;
    alsa.enable = true;
    pulse.enable = true;
    jack.enable = true;
  };

  xdg.portal = {
    enable = true;
    # wlr.enable = true;
    extraPortals = with pkgs; [
    # xdg-desktop-portal-wlr
    xdg-desktop-portal-gtk
    ];
  };

  hardware.opengl = {
    enable = true;
    driSupport32Bit = true;
    extraPackages = with pkgs; [
      intel-compute-runtime
    ];
  };

  hardware.opentabletdriver.enable = true;

  # Define a user account. Don't forget to set a password with ‘passwd’.
  users.users.tacocat = {
    isNormalUser = true;
    extraGroups = ["wheel" "networkmanager" "audio" "video" "bluetooth" "kvm"];
    home = "/home/tacocat";
    description = "Aria Nolan";
  };

  programs.sway.enable = true;
  programs.sway.wrapperFeatures.gtk = true;
  programs.sway.extraPackages = with pkgs; [
    swaylock
    swayidle
    brightnessctl
    wl-mirror
  ];

  programs.waybar.enable = true;
  programs.steam.enable = true;
  nixpkgs.config.allowUnfreePredicate = pkg: builtins.elem (lib.getName pkg) [
    "steam"
    "steam-original"
    "steam-run"
  ];

  environment = {
    systemPackages = with pkgs; [
      vim
      exfat
      encfs
      ntfs3g
    ];
    defaultPackages = with pkgs; [
      perl
      rsync
      strace
    ];

    # TODO configure this under sway with home-manager
    variables = {
      SDL_VIDEODRIVER = "wayland";
      QT_QPA_PLATFORM = "wayland";
      QT_WAYLAND_DISABLE_WINDOWDECORATIONS = "1";
      _JAVA_AWT_WM_NONREPARENTING = "1";
      MOZ_ENABLE_WAYLAND = "1";
    };
  };

  # This value determines the NixOS release from which the default
  # settings for stateful data, like file locations and database versions
  # on your system were taken. It's perfectly fine and recommended to leave
  # this value at the release version of the first install of this system.
  # Before changing this value read the documentation for this option
  # (e.g. man configuration.nix or on https://nixos.org/nixos/options.html).
  system.stateVersion = "23.05"; # Did you read the comment?
}
